/**
    @file ft51.h

    @brief     General FT51 header file.

    Include this header to access definitions, types and macros
    for the core properties of the FT51: Special Function 
    Registers, IO MUX, and library return values.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_H__
#define __FT51_H__

#include <stdint.h>
#include "ft51_sfr.h"
#include "ft51_iomux.h"

/**
    @enum  FT51_STATUS
    @brief Generic return codes.
**/
typedef enum
{
    /** The operation succeeded. **/
    FT51_OK                     = 0x00,
    /** The operation failed. **/
    FT51_FAILED                 = 0x01,
    /** An invalid parameter was passed to the function. **/
    FT51_INVALID_PARAMETER      = 0x02,
    /** The object, device or file could not be found. **/
    FT51_NOT_FOUND              = 0x03,
    /** The requested device or object is already in use. **/
    FT51_UNAVAILABLE            = 0x04,
    // the last entry is just for looping over the enum
    FT51_STATUS_FINAL           = 0xFF
} FT51_STATUS;

/* Helper macro to count elements in an array. */
#ifndef _countof
#define _countof(a) (sizeof(a)/sizeof(*(a)))
#endif /* _countof */

/* Helper macro to get most-significant byte of a 2-byte variable. */
#ifndef MSB
#define MSB(x) (uint8_t)(((uint16_t)(x) >> 8) & 0x00ff)
#endif /* MSB */

/* Helper macro to get least-significant byte of a 2-byte variable. */
#ifndef LSB
#define LSB(x) (uint8_t)((uint16_t)(x) & 0x00ff)
#endif /* LSB */

/* Explicit False definition for Boolean-style functions. */
#ifndef FALSE
#define FALSE 0
#endif /* FALSE */

/* Explicit True definition for Boolean-style functions. */
#ifndef TRUE
#define TRUE !FALSE
#endif /* TRUE */

/** Enable all interrupts (standard 8051 and FTDI extensions). **/ 
#define ENABLE_INTERRUPTS  IE = 0x8F

/** Disable all interrupts (standard 8051 and FTDI extensions). **/ 
#define DISABLE_INTERRUPTS IE = 0x8A

#endif // __FT51_H__