/**
    @file ft51_debug.h

    @brief Debug library. 
	
	Print formatted strings via the debug UART.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_DEBUG_H__
#define __FT51_DEBUG_H__

#include <stdint.h>
#include <stdarg.h>
#include "ft51_iomux.h"

/**
    @brief          debug_initialise

    Initialise the debug UART for debug purposes.
 
    @param[in]      tx_pad  Pad to which the debug messages should be sent.
**/
void debug_initialise(IOMUX_PAD tx_pad);

/**
    @brief          debug_printf

    Output a formatted string via the debug UART.
    @note           Print function blocks code execution while sending data via
                    UART.
 
    @param[in]      format          Text to be formatted
    @param[in]      ...             Arguments to be inserted into formatted 
                                    text
**/
void debug_printf(const char *format,
                         ...);

/**
    @brief          debug_hexdump

    Output hex values for a range of data memory.
 
    @param[in]      address  First location to be displayed.
    @param[in]      length   Number of locations to display.
**/
void debug_hexdump(uint8_t  *address,
                   uint16_t  length);

/**
    @brief          debug_peripheral_registers

    Output hex values for a range of peripheral
    control registers.
 
    @param[in]      start   First register to be displayed.
    @param[in]      end     Final register to be displayed.
**/
void debug_peripheral_registers(uint16_t  start,
                                uint16_t  end);

#endif // __FT51_DEBUG_H__