/**
    @file ft51_usb_configuration.c

    @brief USB Library API set/get configuration request handler function.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdint.h>
#include <stdlib.h>
#include "ft51.h"
#include "ft51_usb.h"
#include "ft51_usb_internal.h"

FT51_STATUS USB_req_set_configuration(USB_device_request *req)
{
    if (USB_current_state >= ADDRESS)
    {
        // A value greater than zero means that the device is configured.
        if (req->wValue)
            USB_current_state = CONFIGURED;
        else
            USB_current_state = ADDRESS;

        // Application must make sure configuration selected is valid.
        USB_configuration = req->wValue & 0xFF;

        USB_transfer(USB_EP_0, USB_DIR_IN, NULL, 0);

        return FT51_OK;
    }
    return FT51_FAILED;
}

FT51_STATUS USB_req_get_configuration(void)
{
    USB_transfer(USB_EP_0, USB_DIR_IN, &USB_configuration, 1);
    return FT51_OK;
}